@@ -2,12 +2,16 @@
 # This file is part of snmpsim software.
 #
 # Copyright (c) 2010-2019, Ilya Etingof <etingof@gmail.com>
-# License: http://snmplabs.com/snmpsim/license.html
+# License: https://www.pysnmp.com/snmpsim/license.html
 #
-class SnmpsimError(Exception): pass
 
 
-class NoDataNotification(SnmpsimError): pass
+class SnmpsimError(Exception):
+    pass
+
+
+class NoDataNotification(SnmpsimError):
+    pass
 
 
 class MoreDataNotification(SnmpsimError):
