@@ -2,12 +2,12 @@
 # This file is part of snmpsim software.
 #
 # Copyright (c) 2010-2019, Ilya Etingof <etingof@gmail.com>
-# License: http://snmplabs.com/snmpsim/license.html
+# License: https://www.pysnmp.com/snmpsim/license.html
 #
-from snmpsim.record import dump
 from snmpsim.grammar import sap
+from snmpsim.record import dump
 
 
 class SapRecord(dump.DumpRecord):
     grammar = sap.SapGrammar()
-    ext = 'sapwalk'
+    ext = "sapwalk"
